# libpythonpro2
Criado para curso pyTools

Link do curso: [Python Pro](https://plataforma.dev.pro.br/)

Suportada versão 3 do Python

Topicos a seremm abordados:
1-Git
2-Virtualenv
3-Pip
[![Build Status](https://travis-ci.com/EstudosPython/libpythonpro2.svg?token=hxgdVvd52hyYrMw5v15K&branch=main)](https://travis-ci.com/EstudosPython/libpythonpro2)